@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import functools
 import inspect
@@ -6,7 +8,7 @@ import typing as t
 
 from fastapi import Request
 from fastapi.routing import APIRoute
-from pydantic.color import Color
+from pydantic_extra_types.color import Color
 from starlette.routing import Match
 
 
@@ -24,7 +26,7 @@ def import_string(import_name: str) -> t.Any:
     try:
         return getattr(module, obj_name)
     except AttributeError as e:
-        raise ImportError(e)
+        raise ImportError(e) from None
 
 
 def get_name_from_obj(obj: t.Any) -> str:
@@ -38,7 +40,7 @@ def get_name_from_obj(obj: t.Any) -> str:
     return name
 
 
-def matched_route(request: Request) -> t.Optional[APIRoute]:
+def matched_route(request: Request) -> APIRoute | None:
     for route in request.app.routes:
         match, _ = route.matches(request.scope)
 
